@@ -15,9 +15,10 @@ import presettings
 
 
 class DownLinkAdmin(admin.ModelAdmin):
-    def __call__(self, request, * args, ** kwargs):
+    def queryset(self, request):
+        """catch the request object for list pages"""
         self.request = request
-        return super(DownLinkAdmin, self).__call__(request, * args, ** kwargs)
+        return super(DownLinkAdmin, self).queryset(request)
 
     list_display = ('slug', 'active', 'file', 'valid', 'clicks', 'timestamp_creation', 'link')
     actions = ['make_link']
