@@ -14,6 +14,7 @@ from django.utils.translation import ugettext_lazy as _
 import random
 import os
 import datetime
+from django.utils import timezone
 
 class Download(models.Model):
     slug = models.SlugField(verbose_name=_('slug'), blank=False, unique=True)
@@ -54,7 +55,7 @@ class Download(models.Model):
     def timeout_time(self):
         """If timout time is reached it returs True"""
         if not self.timeout_hours == 0: # never timeout through time
-            if self.timestamp_creation + datetime.timedelta(hours=self.timeout_hours) < datetime.datetime.now():
+            if self.timestamp_creation + datetime.timedelta(hours=self.timeout_hours) < timezone.now():
                 return True
 
     def timeout(self):
@@ -70,7 +71,7 @@ class Download(models.Model):
         """Is shown at the admit list display"""
         if self.timeout_hours == 0:
             return '<span style="color: #FF7F00; ">%s</span>' % unicode(_(u'never expires'))
-        return (self.timestamp_creation + datetime.timedelta(hours=self.timeout_hours)) - datetime.datetime.now()
+        return (self.timestamp_creation + datetime.timedelta(hours=self.timeout_hours)) - timezone.now()
 
     def set_link(self, file, slug='autogenerated', timeout=None, maxclicks=None):
         self.slug = slug
