@@ -2,12 +2,16 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-import django
-import sys
-
-VERSION = (0,5,5,0)
-RELEASE_DJANGO = ((1,2),(1,3))
+VERSION = (0,5,6,2)
+RELEASE_DJANGO = ((1,2),(1,3),(1,4))
 PYTHON_MIN = (2,4)
+REQUIRES ="""
+django-dynamic-link 0.5.5 => Django 1.2, 1.3 :: Python >= 2.4 :: Example project: Django 1.3
+django-dynamic-link 0.6.x => Django 1.2, 1.3, 1.4(Python 2.5) :: Python >= 2.4 :: Example project: Django 1.4, Python 2.5
+
+(for an actual release visit http://pypi.python.org/pypi/django-dynamic-link/)
+"""
+
 APPLICATION_NAME = "Dynamic Link"
 VERSION_str = str(VERSION[:3]).strip('()').replace(',','.').replace(' ','')
 VERSION_INFO = """
@@ -15,8 +19,10 @@ Version: %s
 Modification date: 03.08.2011
 
 Hints:
-
-
+- 0.5.6.2   settings.py in example project modified. Now it should work correct with Django 1.4
+- 0.5.6.1   Timezone bug changes
+- 0.5.6     Example Project runs with Django 1.4
+- 0.5.5     dynamicLink.CKISNT() function added.
 - 0.5.4.1   Canges in setup.py - READM will now alsow be installed. Now if a package
             is installed than help(dynamicLink) outputs the README.
 - 0.5.4     Bugfix: Installation failed on Windows in spite of "/" on the end
